@@ -76,7 +76,8 @@ where
     T: BitSetLimit,
     B: BitSetLimit,
 {
-    const MAX_SET_INDEX: usize = crate::max(T::MAX_SET_INDEX + 1, N) * (B::MAX_SET_INDEX + 1);
+    const MAX_SET_INDEX: usize =
+        crate::max(T::MAX_SET_INDEX, N - 1) * (B::MAX_SET_INDEX + 1) + B::MAX_SET_INDEX;
 }
 
 impl<T, B, const N: usize> BitSet for Layered<T, B, N>
